@@ -1,9 +1,10 @@
 #' In-development help for package loaded with devtools
 #'
-#' `dev_help` searches for source documentation provided in
-#' packages loaded by devtools. To improve performance, the `.Rd` files
-#' are parsed to create to index once, then cached. Use
-#' `dev_topic_index_reset` to clear that index.
+#' `dev_help()` searches for source documentation provided in packages
+#' loaded by devtools. To improve performance, the `.Rd` files are
+#' parsed to create to index once, then cached. Use
+#' `dev_topic_index_reset()` to clear that index. You can manually
+#' retrieve the index for a local package with `dev_topic_index()`.
 #'
 #' @param topic name of help to search for.
 #' @param dev_packages A character vector of package names to search within.
@@ -22,11 +23,12 @@
 #' load_all("ggplot2")
 #' dev_help("ggplot") # loads development documentation for ggplot
 #' }
-dev_help <- function(topic,
-                     dev_packages = NULL,
-                     stage = "render",
-                     type = getOption("help_type")) {
-
+dev_help <- function(
+  topic,
+  dev_packages = NULL,
+  stage = "render",
+  type = getOption("help_type")
+) {
   if (length(dev_packages()) == 0) {
     cli::cli_abort(c(
       "Can't find development documentation because no in-development packages loaded.",
@@ -83,15 +85,19 @@ load_rd_macros <- function(dir) {
 
 #' @export
 print.dev_topic <- function(x, ...) {
-  cli::cli_inform(c("i" = "Rendering development documentation for {.val {x$topic}}"))
+  cli::cli_inform(c(
+    "i" = "Rendering development documentation for {.val {x$topic}}"
+  ))
 
   type <- arg_match0(x$type %||% "text", c("text", "html"))
 
   # Use rstudio's previewRd() if possible
-  if (type == "html" && is_rstudio() && is_installed("rstudioapi")) {
+  if (type == "html" && rstudioapi_available()) {
     # If the package has Rd macros, this needs a version of rstudio
     # that loads them, see rstudio/rstudio#12111
-    version_needed <- if (has_rd_macros(dirname(dirname(x$path)))) "2022.12.0.256"
+    version_needed <- if (has_rd_macros(dirname(dirname(x$path)))) {
+      "2022.12.0.256"
+    }
 
     if (rstudioapi::hasFun("previewRd", version_needed = version_needed)) {
       return(rstudioapi::callFun("previewRd", x$path))
@@ -162,7 +168,8 @@ topic_write_html <- function(x, path) {
 }
 
 topic_lines <- function(x, type = c("text", "html")) {
-  file <- withr::local_tempfile()
+  file <- tempfile()
+  defer(unlink(file))
 
   switch(
     arg_match(type),
@@ -260,16 +267,21 @@ shim_help <- function(topic, package = NULL, ...) {
   package_name <- substitute(package)
   if (is_symbol(package_name)) {
     package_str <- as_string(package_name)
-  } else if (is_null(package_name)) {
-    package_str <- NULL
   } else {
+    # Complex expression, just evaluate it (#266). The value is
+    # injected in `utils::help(package = )` below, causing it to be
+    # interpreted as is.
     package_str <- package
-    package_name <- sym(package)
+    package_name <- package
   }
 
   use_dev <-
-    (!missing(topic) && is_string(package_str) && package_str %in% dev_packages()) ||
-    (!missing(topic_name) && is_null(package_str) && !is_null(dev_topic_find(topic_str)))
+    (!missing(topic) &&
+      is_string(package_str) &&
+      package_str %in% dev_packages()) ||
+    (!missing(topic_name) &&
+      is_null(package_str) &&
+      !is_null(dev_topic_find(topic_str)))
 
   if (use_dev) {
     dev_help(topic_str, package_str)
